# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_trading_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$exchange/injective_trading_rpc.proto\x12\x15injective_trading_rpc\"\xf6\x02\n\x1cListTradingStrategiesRequest\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\tR\x0e\x61\x63\x63ountAddress\x12+\n\x11pending_execution\x18\x05 \x01(\x08R\x10pendingExecution\x12\x1d\n\nstart_time\x18\x06 \x01(\x12R\tstartTime\x12\x19\n\x08\x65nd_time\x18\x07 \x01(\x12R\x07\x65ndTime\x12\x14\n\x05limit\x18\x08 \x01(\x11R\x05limit\x12\x12\n\x04skip\x18\t \x01(\x04R\x04skip\x12#\n\rstrategy_type\x18\n \x03(\tR\x0cstrategyType\x12\x1f\n\x0bmarket_type\x18\x0b \x01(\tR\nmarketType\"\x9e\x01\n\x1dListTradingStrategiesResponse\x12\x46\n\nstrategies\x18\x01 \x03(\x0b\x32&.injective_trading_rpc.TradingStrategyR\nstrategies\x12\x35\n\x06paging\x18\x02 \x01(\x0b\x32\x1d.injective_trading_rpc.PagingR\x06paging\"\xd9\n\n\x0fTradingStrategy\x12\x14\n\x05state\x18\x01 \x01(\tR\x05state\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12#\n\rsubaccount_id\x18\x03 \x01(\tR\x0csubaccountId\x12\'\n\x0f\x61\x63\x63ount_address\x18\x04 \x01(\tR\x0e\x61\x63\x63ountAddress\x12)\n\x10\x63ontract_address\x18\x05 \x01(\tR\x0f\x63ontractAddress\x12\'\n\x0f\x65xecution_price\x18\x06 \x01(\tR\x0e\x65xecutionPrice\x12#\n\rbase_quantity\x18\x07 \x01(\tR\x0c\x62\x61seQuantity\x12%\n\x0equote_quantity\x18\x14 \x01(\tR\rquoteQuantity\x12\x1f\n\x0blower_bound\x18\x08 \x01(\tR\nlowerBound\x12\x1f\n\x0bupper_bound\x18\t \x01(\tR\nupperBound\x12\x1b\n\tstop_loss\x18\n \x01(\tR\x08stopLoss\x12\x1f\n\x0btake_profit\x18\x0b \x01(\tR\ntakeProfit\x12\x19\n\x08swap_fee\x18\x0c \x01(\tR\x07swapFee\x12!\n\x0c\x62\x61se_deposit\x18\x11 \x01(\tR\x0b\x62\x61seDeposit\x12#\n\rquote_deposit\x18\x12 \x01(\tR\x0cquoteDeposit\x12(\n\x10market_mid_price\x18\x13 \x01(\tR\x0emarketMidPrice\x12>\n\x1bsubscription_quote_quantity\x18\x15 \x01(\tR\x19subscriptionQuoteQuantity\x12<\n\x1asubscription_base_quantity\x18\x16 \x01(\tR\x18subscriptionBaseQuantity\x12\x31\n\x15number_of_grid_levels\x18\x17 \x01(\tR\x12numberOfGridLevels\x12<\n\x1bshould_exit_with_quote_only\x18\x18 \x01(\x08R\x17shouldExitWithQuoteOnly\x12\x1f\n\x0bstop_reason\x18\x19 \x01(\tR\nstopReason\x12+\n\x11pending_execution\x18\x1a \x01(\x08R\x10pendingExecution\x12%\n\x0e\x63reated_height\x18\r \x01(\x12R\rcreatedHeight\x12%\n\x0eremoved_height\x18\x0e \x01(\x12R\rremovedHeight\x12\x1d\n\ncreated_at\x18\x0f \x01(\x12R\tcreatedAt\x12\x1d\n\nupdated_at\x18\x10 \x01(\x12R\tupdatedAt\x12\x1b\n\texit_type\x18\x1b \x01(\tR\x08\x65xitType\x12K\n\x10stop_loss_config\x18\x1c \x01(\x0b\x32!.injective_trading_rpc.ExitConfigR\x0estopLossConfig\x12O\n\x12take_profit_config\x18\x1d \x01(\x0b\x32!.injective_trading_rpc.ExitConfigR\x10takeProfitConfig\x12#\n\rstrategy_type\x18\x1e \x01(\tR\x0cstrategyType\x12)\n\x10\x63ontract_version\x18\x1f \x01(\tR\x0f\x63ontractVersion\x12#\n\rcontract_name\x18  \x01(\tR\x0c\x63ontractName\x12\x1f\n\x0bmarket_type\x18! \x01(\tR\nmarketType\"H\n\nExitConfig\x12\x1b\n\texit_type\x18\x01 \x01(\tR\x08\x65xitType\x12\x1d\n\nexit_price\x18\x02 \x01(\tR\texitPrice\"\x86\x01\n\x06Paging\x12\x14\n\x05total\x18\x01 \x01(\x12R\x05total\x12\x12\n\x04\x66rom\x18\x02 \x01(\x11R\x04\x66rom\x12\x0e\n\x02to\x18\x03 \x01(\x11R\x02to\x12.\n\x13\x63ount_by_subaccount\x18\x04 \x01(\x12R\x11\x63ountBySubaccount\x12\x12\n\x04next\x18\x05 \x03(\tR\x04next2\x9a\x01\n\x13InjectiveTradingRPC\x12\x82\x01\n\x15ListTradingStrategies\x12\x33.injective_trading_rpc.ListTradingStrategiesRequest\x1a\x34.injective_trading_rpc.ListTradingStrategiesResponseB\xbb\x01\n\x19\x63om.injective_trading_rpcB\x18InjectiveTradingRpcProtoP\x01Z\x18/injective_trading_rpcpb\xa2\x02\x03IXX\xaa\x02\x13InjectiveTradingRpc\xca\x02\x13InjectiveTradingRpc\xe2\x02\x1fInjectiveTradingRpc\\GPBMetadata\xea\x02\x13InjectiveTradingRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_trading_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.injective_trading_rpcB\030InjectiveTradingRpcProtoP\001Z\030/injective_trading_rpcpb\242\002\003IXX\252\002\023InjectiveTradingRpc\312\002\023InjectiveTradingRpc\342\002\037InjectiveTradingRpc\\GPBMetadata\352\002\023InjectiveTradingRpc'
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_start=64
  _globals['_LISTTRADINGSTRATEGIESREQUEST']._serialized_end=438
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_start=441
  _globals['_LISTTRADINGSTRATEGIESRESPONSE']._serialized_end=599
  _globals['_TRADINGSTRATEGY']._serialized_start=602
  _globals['_TRADINGSTRATEGY']._serialized_end=1971
  _globals['_EXITCONFIG']._serialized_start=1973
  _globals['_EXITCONFIG']._serialized_end=2045
  _globals['_PAGING']._serialized_start=2048
  _globals['_PAGING']._serialized_end=2182
  _globals['_INJECTIVETRADINGRPC']._serialized_start=2185
  _globals['_INJECTIVETRADINGRPC']._serialized_end=2339
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/evidence.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from pyinjective.proto.tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1ftendermint/types/evidence.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto\"\xe4\x01\n\x08\x45vidence\x12\x61\n\x17\x64uplicate_vote_evidence\x18\x01 \x01(\x0b\x32\'.tendermint.types.DuplicateVoteEvidenceH\x00R\x15\x64uplicateVoteEvidence\x12n\n\x1clight_client_attack_evidence\x18\x02 \x01(\x0b\x32+.tendermint.types.LightClientAttackEvidenceH\x00R\x19lightClientAttackEvidenceB\x05\n\x03sum\"\x90\x02\n\x15\x44uplicateVoteEvidence\x12-\n\x06vote_a\x18\x01 \x01(\x0b\x32\x16.tendermint.types.VoteR\x05voteA\x12-\n\x06vote_b\x18\x02 \x01(\x0b\x32\x16.tendermint.types.VoteR\x05voteB\x12,\n\x12total_voting_power\x18\x03 \x01(\x03R\x10totalVotingPower\x12\'\n\x0fvalidator_power\x18\x04 \x01(\x03R\x0evalidatorPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"\xcd\x02\n\x19LightClientAttackEvidence\x12I\n\x11\x63onflicting_block\x18\x01 \x01(\x0b\x32\x1c.tendermint.types.LightBlockR\x10\x63onflictingBlock\x12#\n\rcommon_height\x18\x02 \x01(\x03R\x0c\x63ommonHeight\x12N\n\x14\x62yzantine_validators\x18\x03 \x03(\x0b\x32\x1b.tendermint.types.ValidatorR\x13\x62yzantineValidators\x12,\n\x12total_voting_power\x18\x04 \x01(\x03R\x10totalVotingPower\x12\x42\n\ttimestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\ttimestamp\"L\n\x0c\x45videnceList\x12<\n\x08\x65vidence\x18\x01 \x03(\x0b\x32\x1a.tendermint.types.EvidenceB\x04\xc8\xde\x1f\x00R\x08\x65videnceB\xbb\x01\n\x14\x63om.tendermint.typesB\rEvidenceProtoP\x01Z3github.com/cometbft/cometbft/proto/tendermint/types\xa2\x02\x03TTX\xaa\x02\x10Tendermint.Types\xca\x02\x10Tendermint\\Types\xe2\x02\x1cTendermint\\Types\\GPBMetadata\xea\x02\x11Tendermint::Typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.evidence_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tendermint.typesB\rEvidenceProtoP\001Z3github.com/cometbft/cometbft/proto/tendermint/types\242\002\003TTX\252\002\020Tendermint.Types\312\002\020Tendermint\\Types\342\002\034Tendermint\\Types\\GPBMetadata\352\002\021Tendermint::Types'
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_DUPLICATEVOTEEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._loaded_options = None
  _globals['_LIGHTCLIENTATTACKEVIDENCE'].fields_by_name['timestamp']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._loaded_options = None
  _globals['_EVIDENCELIST'].fields_by_name['evidence']._serialized_options = b'\310\336\037\000'
  _globals['_EVIDENCE']._serialized_start=173
  _globals['_EVIDENCE']._serialized_end=401
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_start=404
  _globals['_DUPLICATEVOTEEVIDENCE']._serialized_end=676
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_start=679
  _globals['_LIGHTCLIENTATTACKEVIDENCE']._serialized_end=1012
  _globals['_EVIDENCELIST']._serialized_start=1014
  _globals['_EVIDENCELIST']._serialized_end=1090
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.permissions.v1beta1 import (
    query_pb2 as permissions_query_pb,
    query_pb2_grpc as permissions_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcPermissionsApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._stub = permissions_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._stub.Params, request=request)

        return response

    async def fetch_all_namespaces(self) -> Dict[str, Any]:
        request = permissions_query_pb.QueryAllNamespacesRequest()
        response = await self._execute_call(call=self._stub.AllNamespaces, request=request)

        return response

    async def fetch_namespace_by_denom(self, denom: str, include_roles: bool) -> Dict[str, Any]:
        request = permissions_query_pb.QueryNamespaceByDenomRequest(denom=denom, include_roles=include_roles)
        response = await self._execute_call(call=self._stub.NamespaceByDenom, request=request)

        return response

    async def fetch_address_roles(self, denom: str, address: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryAddressRolesRequest(denom=denom, address=address)
        response = await self._execute_call(call=self._stub.AddressRoles, request=request)

        return response

    async def fetch_addresses_by_role(self, denom: str, role: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryAddressesByRoleRequest(denom=denom, role=role)
        response = await self._execute_call(call=self._stub.AddressesByRole, request=request)

        return response

    async def fetch_vouchers_for_address(self, address: str) -> Dict[str, Any]:
        request = permissions_query_pb.QueryVouchersForAddressRequest(address=address)
        response = await self._execute_call(call=self._stub.VouchersForAddress, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/connection/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.ibc.core.client.v1 import client_pb2 as ibc_dot_core_dot_client_dot_v1_dot_client__pb2
from pyinjective.proto.ibc.core.connection.v1 import connection_pb2 as ibc_dot_core_dot_connection_dot_v1_dot_connection__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ibc/core/connection/v1/query.proto\x12\x16ibc.core.connection.v1\x1a\x14gogoproto/gogo.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x1fibc/core/client/v1/client.proto\x1a\'ibc/core/connection/v1/connection.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x19google/protobuf/any.proto\"=\n\x16QueryConnectionRequest\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\"\xbb\x01\n\x17QueryConnectionResponse\x12\x45\n\nconnection\x18\x01 \x01(\x0b\x32%.ibc.core.connection.v1.ConnectionEndR\nconnection\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"a\n\x17QueryConnectionsRequest\x12\x46\n\npagination\x18\x01 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination\"\xed\x01\n\x18QueryConnectionsResponse\x12N\n\x0b\x63onnections\x18\x01 \x03(\x0b\x32,.ibc.core.connection.v1.IdentifiedConnectionR\x0b\x63onnections\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\x12\x38\n\x06height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x06height\"<\n\x1dQueryClientConnectionsRequest\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\"\xa6\x01\n\x1eQueryClientConnectionsResponse\x12)\n\x10\x63onnection_paths\x18\x01 \x03(\tR\x0f\x63onnectionPaths\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"H\n!QueryConnectionClientStateRequest\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\"\xe2\x01\n\"QueryConnectionClientStateResponse\x12\x61\n\x17identified_client_state\x18\x01 \x01(\x0b\x32).ibc.core.client.v1.IdentifiedClientStateR\x15identifiedClientState\x12\x14\n\x05proof\x18\x02 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x03 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\x9d\x01\n$QueryConnectionConsensusStateRequest\x12#\n\rconnection_id\x18\x01 \x01(\tR\x0c\x63onnectionId\x12\'\n\x0frevision_number\x18\x02 \x01(\x04R\x0erevisionNumber\x12\'\n\x0frevision_height\x18\x03 \x01(\x04R\x0erevisionHeight\"\xde\x01\n%QueryConnectionConsensusStateResponse\x12=\n\x0f\x63onsensus_state\x18\x01 \x01(\x0b\x32\x14.google.protobuf.AnyR\x0e\x63onsensusState\x12\x1b\n\tclient_id\x18\x02 \x01(\tR\x08\x63lientId\x12\x14\n\x05proof\x18\x03 \x01(\x0cR\x05proof\x12\x43\n\x0cproof_height\x18\x04 \x01(\x0b\x32\x1a.ibc.core.client.v1.HeightB\x04\xc8\xde\x1f\x00R\x0bproofHeight\"\x1e\n\x1cQueryConnectionParamsRequest\"W\n\x1dQueryConnectionParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32\x1e.ibc.core.connection.v1.ParamsR\x06params2\xb9\t\n\x05Query\x12\xaa\x01\n\nConnection\x12..ibc.core.connection.v1.QueryConnectionRequest\x1a/.ibc.core.connection.v1.QueryConnectionResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/ibc/core/connection/v1/connections/{connection_id}\x12\x9d\x01\n\x0b\x43onnections\x12/.ibc.core.connection.v1.QueryConnectionsRequest\x1a\x30.ibc.core.connection.v1.QueryConnectionsResponse\"+\x82\xd3\xe4\x93\x02%\x12#/ibc/core/connection/v1/connections\x12\xc2\x01\n\x11\x43lientConnections\x12\x35.ibc.core.connection.v1.QueryClientConnectionsRequest\x1a\x36.ibc.core.connection.v1.QueryClientConnectionsResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/ibc/core/connection/v1/client_connections/{client_id}\x12\xd8\x01\n\x15\x43onnectionClientState\x12\x39.ibc.core.connection.v1.QueryConnectionClientStateRequest\x1a:.ibc.core.connection.v1.QueryConnectionClientStateResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/ibc/core/connection/v1/connections/{connection_id}/client_state\x12\x98\x02\n\x18\x43onnectionConsensusState\x12<.ibc.core.connection.v1.QueryConnectionConsensusStateRequest\x1a=.ibc.core.connection.v1.QueryConnectionConsensusStateResponse\"\x7f\x82\xd3\xe4\x93\x02y\x12w/ibc/core/connection/v1/connections/{connection_id}/consensus_state/revision/{revision_number}/height/{revision_height}\x12\xa7\x01\n\x10\x43onnectionParams\x12\x34.ibc.core.connection.v1.QueryConnectionParamsRequest\x1a\x35.ibc.core.connection.v1.QueryConnectionParamsResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/ibc/core/connection/v1/paramsB\xe1\x01\n\x1a\x63om.ibc.core.connection.v1B\nQueryProtoP\x01Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\xa2\x02\x03ICC\xaa\x02\x16Ibc.Core.Connection.V1\xca\x02\x16Ibc\\Core\\Connection\\V1\xe2\x02\"Ibc\\Core\\Connection\\V1\\GPBMetadata\xea\x02\x19Ibc::Core::Connection::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ibc.core.connection.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.ibc.core.connection.v1B\nQueryProtoP\001Z<github.com/cosmos/ibc-go/v8/modules/core/03-connection/types\242\002\003ICC\252\002\026Ibc.Core.Connection.V1\312\002\026Ibc\\Core\\Connection\\V1\342\002\"Ibc\\Core\\Connection\\V1\\GPBMetadata\352\002\031Ibc::Core::Connection::V1'
  _globals['_QUERYCONNECTIONRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONSRESPONSE'].fields_by_name['height']._loaded_options = None
  _globals['_QUERYCONNECTIONSRESPONSE'].fields_by_name['height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._loaded_options = None
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE'].fields_by_name['proof_height']._serialized_options = b'\310\336\037\000'
  _globals['_QUERY'].methods_by_name['Connection']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Connection']._serialized_options = b'\202\323\344\223\0025\0223/ibc/core/connection/v1/connections/{connection_id}'
  _globals['_QUERY'].methods_by_name['Connections']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Connections']._serialized_options = b'\202\323\344\223\002%\022#/ibc/core/connection/v1/connections'
  _globals['_QUERY'].methods_by_name['ClientConnections']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ClientConnections']._serialized_options = b'\202\323\344\223\0028\0226/ibc/core/connection/v1/client_connections/{client_id}'
  _globals['_QUERY'].methods_by_name['ConnectionClientState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionClientState']._serialized_options = b'\202\323\344\223\002B\022@/ibc/core/connection/v1/connections/{connection_id}/client_state'
  _globals['_QUERY'].methods_by_name['ConnectionConsensusState']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionConsensusState']._serialized_options = b'\202\323\344\223\002y\022w/ibc/core/connection/v1/connections/{connection_id}/consensus_state/revision/{revision_number}/height/{revision_height}'
  _globals['_QUERY'].methods_by_name['ConnectionParams']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ConnectionParams']._serialized_options = b'\202\323\344\223\002 \022\036/ibc/core/connection/v1/params'
  _globals['_QUERYCONNECTIONREQUEST']._serialized_start=259
  _globals['_QUERYCONNECTIONREQUEST']._serialized_end=320
  _globals['_QUERYCONNECTIONRESPONSE']._serialized_start=323
  _globals['_QUERYCONNECTIONRESPONSE']._serialized_end=510
  _globals['_QUERYCONNECTIONSREQUEST']._serialized_start=512
  _globals['_QUERYCONNECTIONSREQUEST']._serialized_end=609
  _globals['_QUERYCONNECTIONSRESPONSE']._serialized_start=612
  _globals['_QUERYCONNECTIONSRESPONSE']._serialized_end=849
  _globals['_QUERYCLIENTCONNECTIONSREQUEST']._serialized_start=851
  _globals['_QUERYCLIENTCONNECTIONSREQUEST']._serialized_end=911
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE']._serialized_start=914
  _globals['_QUERYCLIENTCONNECTIONSRESPONSE']._serialized_end=1080
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST']._serialized_start=1082
  _globals['_QUERYCONNECTIONCLIENTSTATEREQUEST']._serialized_end=1154
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE']._serialized_start=1157
  _globals['_QUERYCONNECTIONCLIENTSTATERESPONSE']._serialized_end=1383
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST']._serialized_start=1386
  _globals['_QUERYCONNECTIONCONSENSUSSTATEREQUEST']._serialized_end=1543
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE']._serialized_start=1546
  _globals['_QUERYCONNECTIONCONSENSUSSTATERESPONSE']._serialized_end=1768
  _globals['_QUERYCONNECTIONPARAMSREQUEST']._serialized_start=1770
  _globals['_QUERYCONNECTIONPARAMSREQUEST']._serialized_end=1800
  _globals['_QUERYCONNECTIONPARAMSRESPONSE']._serialized_start=1802
  _globals['_QUERYCONNECTIONPARAMSRESPONSE']._serialized_end=1889
  _globals['_QUERY']._serialized_start=1892
  _globals['_QUERY']._serialized_end=3101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/types/params.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dtendermint/types/params.proto\x12\x10tendermint.types\x1a\x14gogoproto/gogo.proto\x1a\x1egoogle/protobuf/duration.proto\"\xb2\x02\n\x0f\x43onsensusParams\x12\x33\n\x05\x62lock\x18\x01 \x01(\x0b\x32\x1d.tendermint.types.BlockParamsR\x05\x62lock\x12<\n\x08\x65vidence\x18\x02 \x01(\x0b\x32 .tendermint.types.EvidenceParamsR\x08\x65vidence\x12?\n\tvalidator\x18\x03 \x01(\x0b\x32!.tendermint.types.ValidatorParamsR\tvalidator\x12\x39\n\x07version\x18\x04 \x01(\x0b\x32\x1f.tendermint.types.VersionParamsR\x07version\x12\x30\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1c.tendermint.types.ABCIParamsR\x04\x61\x62\x63i\"I\n\x0b\x42lockParams\x12\x1b\n\tmax_bytes\x18\x01 \x01(\x03R\x08maxBytes\x12\x17\n\x07max_gas\x18\x02 \x01(\x03R\x06maxGasJ\x04\x08\x03\x10\x04\"\xa9\x01\n\x0e\x45videnceParams\x12+\n\x12max_age_num_blocks\x18\x01 \x01(\x03R\x0fmaxAgeNumBlocks\x12M\n\x10max_age_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xc8\xde\x1f\x00\x98\xdf\x1f\x01R\x0emaxAgeDuration\x12\x1b\n\tmax_bytes\x18\x03 \x01(\x03R\x08maxBytes\"?\n\x0fValidatorParams\x12\"\n\rpub_key_types\x18\x01 \x03(\tR\x0bpubKeyTypes:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"+\n\rVersionParams\x12\x10\n\x03\x61pp\x18\x01 \x01(\x04R\x03\x61pp:\x08\xb8\xa0\x1f\x01\xe8\xa0\x1f\x01\"Z\n\x0cHashedParams\x12&\n\x0f\x62lock_max_bytes\x18\x01 \x01(\x03R\rblockMaxBytes\x12\"\n\rblock_max_gas\x18\x02 \x01(\x03R\x0b\x62lockMaxGas\"O\n\nABCIParams\x12\x41\n\x1dvote_extensions_enable_height\x18\x01 \x01(\x03R\x1avoteExtensionsEnableHeightB\xbd\x01\n\x14\x63om.tendermint.typesB\x0bParamsProtoP\x01Z3github.com/cometbft/cometbft/proto/tendermint/types\xa2\x02\x03TTX\xaa\x02\x10Tendermint.Types\xca\x02\x10Tendermint\\Types\xe2\x02\x1cTendermint\\Types\\GPBMetadata\xea\x02\x11Tendermint::Types\xa8\xe2\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.types.params_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tendermint.typesB\013ParamsProtoP\001Z3github.com/cometbft/cometbft/proto/tendermint/types\242\002\003TTX\252\002\020Tendermint.Types\312\002\020Tendermint\\Types\342\002\034Tendermint\\Types\\GPBMetadata\352\002\021Tendermint::Types\250\342\036\001'
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._loaded_options = None
  _globals['_EVIDENCEPARAMS'].fields_by_name['max_age_duration']._serialized_options = b'\310\336\037\000\230\337\037\001'
  _globals['_VALIDATORPARAMS']._loaded_options = None
  _globals['_VALIDATORPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_VERSIONPARAMS']._loaded_options = None
  _globals['_VERSIONPARAMS']._serialized_options = b'\270\240\037\001\350\240\037\001'
  _globals['_CONSENSUSPARAMS']._serialized_start=106
  _globals['_CONSENSUSPARAMS']._serialized_end=412
  _globals['_BLOCKPARAMS']._serialized_start=414
  _globals['_BLOCKPARAMS']._serialized_end=487
  _globals['_EVIDENCEPARAMS']._serialized_start=490
  _globals['_EVIDENCEPARAMS']._serialized_end=659
  _globals['_VALIDATORPARAMS']._serialized_start=661
  _globals['_VALIDATORPARAMS']._serialized_end=724
  _globals['_VERSIONPARAMS']._serialized_start=726
  _globals['_VERSIONPARAMS']._serialized_end=769
  _globals['_HASHEDPARAMS']._serialized_start=771
  _globals['_HASHEDPARAMS']._serialized_end=861
  _globals['_ABCIPARAMS']._serialized_start=863
  _globals['_ABCIPARAMS']._serialized_end=942
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/version/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1etendermint/version/types.proto\x12\x12tendermint.version\x1a\x14gogoproto/gogo.proto\"=\n\x03\x41pp\x12\x1a\n\x08protocol\x18\x01 \x01(\x04R\x08protocol\x12\x1a\n\x08software\x18\x02 \x01(\tR\x08software\"9\n\tConsensus\x12\x14\n\x05\x62lock\x18\x01 \x01(\x04R\x05\x62lock\x12\x10\n\x03\x61pp\x18\x02 \x01(\x04R\x03\x61pp:\x04\xe8\xa0\x1f\x01\x42\xc4\x01\n\x16\x63om.tendermint.versionB\nTypesProtoP\x01Z5github.com/cometbft/cometbft/proto/tendermint/version\xa2\x02\x03TVX\xaa\x02\x12Tendermint.Version\xca\x02\x12Tendermint\\Version\xe2\x02\x1eTendermint\\Version\\GPBMetadata\xea\x02\x13Tendermint::Versionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.version.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.tendermint.versionB\nTypesProtoP\001Z5github.com/cometbft/cometbft/proto/tendermint/version\242\002\003TVX\252\002\022Tendermint.Version\312\002\022Tendermint\\Version\342\002\036Tendermint\\Version\\GPBMetadata\352\002\023Tendermint::Version'
  _globals['_CONSENSUS']._loaded_options = None
  _globals['_CONSENSUS']._serialized_options = b'\350\240\037\001'
  _globals['_APP']._serialized_start=76
  _globals['_APP']._serialized_end=137
  _globals['_CONSENSUS']._serialized_start=139
  _globals['_CONSENSUS']._serialized_end=196
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/libs/bits/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n tendermint/libs/bits/types.proto\x12\x14tendermint.libs.bits\"4\n\x08\x42itArray\x12\x12\n\x04\x62its\x18\x01 \x01(\x03R\x04\x62its\x12\x14\n\x05\x65lems\x18\x02 \x03(\x04R\x05\x65lemsB\xd1\x01\n\x18\x63om.tendermint.libs.bitsB\nTypesProtoP\x01Z7github.com/cometbft/cometbft/proto/tendermint/libs/bits\xa2\x02\x03TLB\xaa\x02\x14Tendermint.Libs.Bits\xca\x02\x14Tendermint\\Libs\\Bits\xe2\x02 Tendermint\\Libs\\Bits\\GPBMetadata\xea\x02\x16Tendermint::Libs::Bitsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tendermint.libs.bits.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\030com.tendermint.libs.bitsB\nTypesProtoP\001Z7github.com/cometbft/cometbft/proto/tendermint/libs/bits\242\002\003TLB\252\002\024Tendermint.Libs.Bits\312\002\024Tendermint\\Libs\\Bits\342\002 Tendermint\\Libs\\Bits\\GPBMetadata\352\002\026Tendermint::Libs::Bits'
  _globals['_BITARRAY']._serialized_start=58
  _globals['_BITARRAY']._serialized_end=110
# @@protoc_insertion_point(module_scope)



import datetime
from abc import ABC, abstractmethod
from http.cookies import SimpleCookie
from typing import List, Optional
from warnings import warn

import grpc
from grpc import ChannelCredentials
from grpc.aio import Call, Metadata


class CookieAssistant(ABC):
    @abstractmethod
    def cookie(self) -> Optional[str]:
        ...

    @abstractmethod
    async def process_response_metadata(self, grpc_call: Call):
        ...

    def metadata(self) -> Metadata:
        cookie = self.cookie()
        metadata = Metadata()
        if cookie is not None and cookie != "":
            metadata.add("cookie", cookie)
        return metadata


class BareMetalLoadBalancedCookieAssistant(CookieAssistant):
    def __init__(self):
        self._cookie: Optional[str] = None

    def cookie(self) -> Optional[str]:
        self._check_cookie_expiration()

        return self._cookie

    async def process_response_metadata(self, grpc_call: Call):
        metadata = await grpc_call.initial_metadata()
        if "set-cookie" in metadata:
            self._cookie = metadata["set-cookie"]

    def _check_cookie_expiration(self):
        if self._is_cookie_expired(cookie_data=self._cookie):
            self._cookie = None

    def _is_cookie_expired(self, cookie_data: str) -> bool:
        # The cookies for these nodes do not expire
        return False


class ExpiringCookieAssistant(CookieAssistant):
    def __init__(self, expiration_time_keys_sequence: List[str], time_format: str):
        self._cookie: Optional[str] = None
        self._expiration_time_keys_sequence = expiration_time_keys_sequence
        self._time_format = time_format

    @classmethod
    def for_kubernetes_public_server(cls):
        return cls(
            expiration_time_keys_sequence=["grpc-cookie", "expires"],
            time_format="%a, %d-%b-%Y %H:%M:%S %Z",
        )

    def cookie(self) -> Optional[str]:
        self._check_cookie_expiration()

        return self._cookie

    async def process_response_metadata(self, grpc_call: Call):
        metadata = await grpc_call.initial_metadata()
        if "set-cookie" in metadata:
            self._cookie = metadata["set-cookie"]

    def _check_cookie_expiration(self):
        if self._is_cookie_expired():
            self._cookie = None

    def _is_cookie_expired(self) -> bool:
        is_expired = False

        if self._cookie is not None:
            cookie = SimpleCookie()
            cookie.load(self._cookie)
            cookie_map = cookie

            for key in self._expiration_time_keys_sequence[:-1]:
                cookie_map = cookie.get(key, {})

            expiration_data: Optional[str] = cookie_map.get(self._expiration_time_keys_sequence[-1], None)
            if expiration_data is not None:
                expiration_time = datetime.datetime.strptime(expiration_data, self._time_format)
                is_expired = datetime.datetime.utcnow() >= expiration_time

        return is_expired


class DisabledCookieAssistant(CookieAssistant):
    def cookie(self) -> Optional[str]:
        return None

    async def process_response_metadata(self, grpc_call: Call):
        pass


class Network:
    def __init__(
        self,
        lcd_endpoint: str,
        tm_websocket_endpoint: str,
        grpc_endpoint: str,
        grpc_exchange_endpoint: str,
        grpc_explorer_endpoint: str,
        chain_stream_endpoint: str,
        chain_id: str,
        fee_denom: str,
        env: str,
        chain_cookie_assistant: CookieAssistant,
        exchange_cookie_assistant: CookieAssistant,
        explorer_cookie_assistant: CookieAssistant,
        official_tokens_list_url: str,
        use_secure_connection: Optional[bool] = None,
        grpc_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_exchange_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_explorer_channel_credentials: Optional[ChannelCredentials] = None,
        chain_stream_channel_credentials: Optional[ChannelCredentials] = None,
    ):
        # the `use_secure_connection` parameter is ignored and will be deprecated soon.
        if use_secure_connection is not None:
            warn(
                "use_secure_connection parameter in Network is no longer used and will be deprecated",
                DeprecationWarning,
                stacklevel=2,
            )

        self.lcd_endpoint = lcd_endpoint
        self.tm_websocket_endpoint = tm_websocket_endpoint
        self.grpc_endpoint = grpc_endpoint
        self.grpc_exchange_endpoint = grpc_exchange_endpoint
        self.grpc_explorer_endpoint = grpc_explorer_endpoint
        self.chain_stream_endpoint = chain_stream_endpoint
        self.chain_id = chain_id
        self.fee_denom = fee_denom
        self.env = env
        self.chain_cookie_assistant = chain_cookie_assistant
        self.exchange_cookie_assistant = exchange_cookie_assistant
        self.explorer_cookie_assistant = explorer_cookie_assistant
        self.official_tokens_list_url = official_tokens_list_url
        self.grpc_channel_credentials = grpc_channel_credentials
        self.grpc_exchange_channel_credentials = grpc_exchange_channel_credentials
        self.grpc_explorer_channel_credentials = grpc_explorer_channel_credentials
        self.chain_stream_channel_credentials = chain_stream_channel_credentials

    @classmethod
    def devnet(cls):
        return cls(
            lcd_endpoint="https://devnet.lcd.injective.dev",
            tm_websocket_endpoint="wss://devnet.tm.injective.dev/websocket",
            grpc_endpoint="devnet.injective.dev:9900",
            grpc_exchange_endpoint="devnet.injective.dev:9910",
            grpc_explorer_endpoint="devnet.injective.dev:9911",
            chain_stream_endpoint="devnet.injective.dev:9999",
            chain_id="injective-777",
            fee_denom="inj",
            env="devnet",
            chain_cookie_assistant=DisabledCookieAssistant(),
            exchange_cookie_assistant=DisabledCookieAssistant(),
            explorer_cookie_assistant=DisabledCookieAssistant(),
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/devnet.json",
        )

    @classmethod
    def testnet(cls, node="lb"):
        nodes = [
            "lb",
            "sentry",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        grpc_channel_credentials = grpc.ssl_channel_credentials()
        grpc_exchange_channel_credentials = grpc.ssl_channel_credentials()
        grpc_explorer_channel_credentials = grpc.ssl_channel_credentials()
        chain_stream_channel_credentials = grpc.ssl_channel_credentials()

        if node == "lb":
            lcd_endpoint = "https://testnet.sentry.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.sentry.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.sentry.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.sentry.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.sentry.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.sentry.chain.stream.injective.network:443"
            chain_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
            exchange_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
            explorer_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        else:
            lcd_endpoint = "https://testnet.lcd.injective.network:443"
            tm_websocket_endpoint = "wss://testnet.tm.injective.network:443/websocket"
            grpc_endpoint = "testnet.chain.grpc.injective.network:443"
            grpc_exchange_endpoint = "testnet.exchange.grpc.injective.network:443"
            grpc_explorer_endpoint = "testnet.explorer.grpc.injective.network:443"
            chain_stream_endpoint = "testnet.chain.stream.injective.network:443"
            chain_cookie_assistant = DisabledCookieAssistant()
            exchange_cookie_assistant = DisabledCookieAssistant()
            explorer_cookie_assistant = DisabledCookieAssistant()

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-888",
            fee_denom="inj",
            env="testnet",
            chain_cookie_assistant=chain_cookie_assistant,
            exchange_cookie_assistant=exchange_cookie_assistant,
            explorer_cookie_assistant=explorer_cookie_assistant,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/testnet.json",
        )

    @classmethod
    def mainnet(cls, node="lb"):
        nodes = [
            "lb",
        ]
        if node not in nodes:
            raise ValueError("Must be one of {}".format(nodes))

        lcd_endpoint = "https://sentry.lcd.injective.network:443"
        tm_websocket_endpoint = "wss://sentry.tm.injective.network:443/websocket"
        grpc_endpoint = "sentry.chain.grpc.injective.network:443"
        grpc_exchange_endpoint = "sentry.exchange.grpc.injective.network:443"
        grpc_explorer_endpoint = "sentry.explorer.grpc.injective.network:443"
        chain_stream_endpoint = "sentry.chain.stream.injective.network:443"
        chain_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        exchange_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        explorer_cookie_assistant = BareMetalLoadBalancedCookieAssistant()
        grpc_channel_credentials = grpc.ssl_channel_credentials()
        grpc_exchange_channel_credentials = grpc.ssl_channel_credentials()
        grpc_explorer_channel_credentials = grpc.ssl_channel_credentials()
        chain_stream_channel_credentials = grpc.ssl_channel_credentials()

        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-1",
            fee_denom="inj",
            env="mainnet",
            chain_cookie_assistant=chain_cookie_assistant,
            exchange_cookie_assistant=exchange_cookie_assistant,
            explorer_cookie_assistant=explorer_cookie_assistant,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/mainnet.json",
        )

    @classmethod
    def local(cls):
        return cls(
            lcd_endpoint="http://localhost:10337",
            tm_websocket_endpoint="ws://localhost:26657/websocket",
            grpc_endpoint="localhost:9900",
            grpc_exchange_endpoint="localhost:9910",
            grpc_explorer_endpoint="localhost:9911",
            chain_stream_endpoint="localhost:9999",
            chain_id="injective-1",
            fee_denom="inj",
            env="local",
            chain_cookie_assistant=DisabledCookieAssistant(),
            exchange_cookie_assistant=DisabledCookieAssistant(),
            explorer_cookie_assistant=DisabledCookieAssistant(),
            official_tokens_list_url="https://github.com/InjectiveLabs/injective-lists/raw/master/tokens/mainnet.json",
        )

    @classmethod
    def custom(
        cls,
        lcd_endpoint,
        tm_websocket_endpoint,
        grpc_endpoint,
        grpc_exchange_endpoint,
        grpc_explorer_endpoint,
        chain_stream_endpoint,
        chain_id,
        env,
        official_tokens_list_url: str,
        chain_cookie_assistant: Optional[CookieAssistant] = None,
        exchange_cookie_assistant: Optional[CookieAssistant] = None,
        explorer_cookie_assistant: Optional[CookieAssistant] = None,
        use_secure_connection: Optional[bool] = None,
        grpc_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_exchange_channel_credentials: Optional[ChannelCredentials] = None,
        grpc_explorer_channel_credentials: Optional[ChannelCredentials] = None,
        chain_stream_channel_credentials: Optional[ChannelCredentials] = None,
    ):
        # the `use_secure_connection` parameter is ignored and will be deprecated soon.
        if use_secure_connection is not None:
            warn(
                "use_secure_connection parameter in Network is no longer used and will be deprecated",
                DeprecationWarning,
                stacklevel=2,
            )

        chain_assistant = chain_cookie_assistant or DisabledCookieAssistant()
        exchange_assistant = exchange_cookie_assistant or DisabledCookieAssistant()
        explorer_assistant = explorer_cookie_assistant or DisabledCookieAssistant()
        return cls(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=grpc_exchange_endpoint,
            grpc_explorer_endpoint=grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id=chain_id,
            fee_denom="inj",
            env=env,
            chain_cookie_assistant=chain_assistant,
            exchange_cookie_assistant=exchange_assistant,
            explorer_cookie_assistant=explorer_assistant,
            official_tokens_list_url=official_tokens_list_url,
            grpc_channel_credentials=grpc_channel_credentials,
            grpc_exchange_channel_credentials=grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=chain_stream_channel_credentials,
        )

    @classmethod
    def custom_chain_and_public_indexer_mainnet(
        cls,
        lcd_endpoint,
        tm_websocket_endpoint,
        grpc_endpoint,
        chain_stream_endpoint,
        chain_cookie_assistant: Optional[CookieAssistant] = None,
    ):
        mainnet_network = cls.mainnet()

        return cls.custom(
            lcd_endpoint=lcd_endpoint,
            tm_websocket_endpoint=tm_websocket_endpoint,
            grpc_endpoint=grpc_endpoint,
            grpc_exchange_endpoint=mainnet_network.grpc_exchange_endpoint,
            grpc_explorer_endpoint=mainnet_network.grpc_explorer_endpoint,
            chain_stream_endpoint=chain_stream_endpoint,
            chain_id="injective-1",
            env="mainnet",
            chain_cookie_assistant=chain_cookie_assistant or DisabledCookieAssistant(),
            exchange_cookie_assistant=mainnet_network.exchange_cookie_assistant,
            explorer_cookie_assistant=mainnet_network.explorer_cookie_assistant,
            official_tokens_list_url=mainnet_network.official_tokens_list_url,
            grpc_channel_credentials=None,
            grpc_exchange_channel_credentials=mainnet_network.grpc_exchange_channel_credentials,
            grpc_explorer_channel_credentials=mainnet_network.grpc_explorer_channel_credentials,
            chain_stream_channel_credentials=None,
        )

    def string(self):
        return self.env

    def create_chain_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_endpoint, self.grpc_channel_credentials)

    def create_exchange_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_exchange_endpoint, self.grpc_exchange_channel_credentials)

    def create_explorer_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.grpc_explorer_endpoint, self.grpc_explorer_channel_credentials)

    def create_chain_stream_grpc_channel(self) -> grpc.Channel:
        return self._create_grpc_channel(self.chain_stream_endpoint, self.chain_stream_channel_credentials)

    def _create_grpc_channel(self, endpoint: str, credentials: Optional[ChannelCredentials]) -> grpc.Channel:
        if credentials is None:
            channel = grpc.aio.insecure_channel(endpoint)
        else:
            channel = grpc.aio.secure_channel(endpoint, credentials)
        return channel



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.injective.permissions.v1beta1 import params_pb2 as injective_dot_permissions_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.permissions.v1beta1 import genesis_pb2 as injective_dot_permissions_dot_v1beta1_dot_genesis__pb2
from pyinjective.proto.injective.permissions.v1beta1 import permissions_pb2 as injective_dot_permissions_dot_v1beta1_dot_permissions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)injective/permissions/v1beta1/query.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a*injective/permissions/v1beta1/params.proto\x1a+injective/permissions/v1beta1/genesis.proto\x1a/injective/permissions/v1beta1/permissions.proto\"\x14\n\x12QueryParamsRequest\"Z\n\x13QueryParamsResponse\x12\x43\n\x06params\x18\x01 \x01(\x0b\x32%.injective.permissions.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x1b\n\x19QueryAllNamespacesRequest\"f\n\x1aQueryAllNamespacesResponse\x12H\n\nnamespaces\x18\x01 \x03(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\nnamespaces\"Y\n\x1cQueryNamespaceByDenomRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12#\n\rinclude_roles\x18\x02 \x01(\x08R\x0cincludeRoles\"g\n\x1dQueryNamespaceByDenomResponse\x12\x46\n\tnamespace\x18\x01 \x01(\x0b\x32(.injective.permissions.v1beta1.NamespaceR\tnamespace\"G\n\x1bQueryAddressesByRoleRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x12\n\x04role\x18\x02 \x01(\tR\x04role\"<\n\x1cQueryAddressesByRoleResponse\x12\x1c\n\taddresses\x18\x01 \x03(\tR\taddresses\"J\n\x18QueryAddressRolesRequest\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"1\n\x19QueryAddressRolesResponse\x12\x14\n\x05roles\x18\x01 \x03(\tR\x05roles\":\n\x1eQueryVouchersForAddressRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\xa0\x01\n\x1fQueryVouchersForAddressResponse\x12}\n\x08vouchers\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinBF\xc8\xde\x1f\x00\xea\xde\x1f\x12vouchers,omitempty\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x08vouchers2\x89\t\n\x05Query\x12\x9e\x01\n\x06Params\x12\x31.injective.permissions.v1beta1.QueryParamsRequest\x1a\x32.injective.permissions.v1beta1.QueryParamsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/permissions/v1beta1/params\x12\xbb\x01\n\rAllNamespaces\x12\x38.injective.permissions.v1beta1.QueryAllNamespacesRequest\x1a\x39.injective.permissions.v1beta1.QueryAllNamespacesResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/permissions/v1beta1/all_namespaces\x12\xc8\x01\n\x10NamespaceByDenom\x12;.injective.permissions.v1beta1.QueryNamespaceByDenomRequest\x1a<.injective.permissions.v1beta1.QueryNamespaceByDenomResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/permissions/v1beta1/namespace_by_denom\x12\xbb\x01\n\x0c\x41\x64\x64ressRoles\x12\x37.injective.permissions.v1beta1.QueryAddressRolesRequest\x1a\x38.injective.permissions.v1beta1.QueryAddressRolesResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/permissions/v1beta1/addresses_by_role\x12\xc4\x01\n\x0f\x41\x64\x64ressesByRole\x12:.injective.permissions.v1beta1.QueryAddressesByRoleRequest\x1a;.injective.permissions.v1beta1.QueryAddressesByRoleResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/injective/permissions/v1beta1/addresses_by_role\x12\xd0\x01\n\x12VouchersForAddress\x12=.injective.permissions.v1beta1.QueryVouchersForAddressRequest\x1a>.injective.permissions.v1beta1.QueryVouchersForAddressResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/permissions/v1beta1/vouchers_for_addressB\x98\x02\n!com.injective.permissions.v1beta1B\nQueryProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\nQueryProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_QUERYVOUCHERSFORADDRESSRESPONSE'].fields_by_name['vouchers']._loaded_options = None
  _globals['_QUERYVOUCHERSFORADDRESSRESPONSE'].fields_by_name['vouchers']._serialized_options = b'\310\336\037\000\352\336\037\022vouchers,omitempty\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\'\022%/injective/permissions/v1beta1/params'
  _globals['_QUERY'].methods_by_name['AllNamespaces']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AllNamespaces']._serialized_options = b'\202\323\344\223\002/\022-/injective/permissions/v1beta1/all_namespaces'
  _globals['_QUERY'].methods_by_name['NamespaceByDenom']._loaded_options = None
  _globals['_QUERY'].methods_by_name['NamespaceByDenom']._serialized_options = b'\202\323\344\223\0023\0221/injective/permissions/v1beta1/namespace_by_denom'
  _globals['_QUERY'].methods_by_name['AddressRoles']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AddressRoles']._serialized_options = b'\202\323\344\223\0022\0220/injective/permissions/v1beta1/addresses_by_role'
  _globals['_QUERY'].methods_by_name['AddressesByRole']._loaded_options = None
  _globals['_QUERY'].methods_by_name['AddressesByRole']._serialized_options = b'\202\323\344\223\0022\0220/injective/permissions/v1beta1/addresses_by_role'
  _globals['_QUERY'].methods_by_name['VouchersForAddress']._loaded_options = None
  _globals['_QUERY'].methods_by_name['VouchersForAddress']._serialized_options = b'\202\323\344\223\0025\0223/injective/permissions/v1beta1/vouchers_for_address'
  _globals['_QUERYPARAMSREQUEST']._serialized_start=342
  _globals['_QUERYPARAMSREQUEST']._serialized_end=362
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=364
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=454
  _globals['_QUERYALLNAMESPACESREQUEST']._serialized_start=456
  _globals['_QUERYALLNAMESPACESREQUEST']._serialized_end=483
  _globals['_QUERYALLNAMESPACESRESPONSE']._serialized_start=485
  _globals['_QUERYALLNAMESPACESRESPONSE']._serialized_end=587
  _globals['_QUERYNAMESPACEBYDENOMREQUEST']._serialized_start=589
  _globals['_QUERYNAMESPACEBYDENOMREQUEST']._serialized_end=678
  _globals['_QUERYNAMESPACEBYDENOMRESPONSE']._serialized_start=680
  _globals['_QUERYNAMESPACEBYDENOMRESPONSE']._serialized_end=783
  _globals['_QUERYADDRESSESBYROLEREQUEST']._serialized_start=785
  _globals['_QUERYADDRESSESBYROLEREQUEST']._serialized_end=856
  _globals['_QUERYADDRESSESBYROLERESPONSE']._serialized_start=858
  _globals['_QUERYADDRESSESBYROLERESPONSE']._serialized_end=918
  _globals['_QUERYADDRESSROLESREQUEST']._serialized_start=920
  _globals['_QUERYADDRESSROLESREQUEST']._serialized_end=994
  _globals['_QUERYADDRESSROLESRESPONSE']._serialized_start=996
  _globals['_QUERYADDRESSROLESRESPONSE']._serialized_end=1045
  _globals['_QUERYVOUCHERSFORADDRESSREQUEST']._serialized_start=1047
  _globals['_QUERYVOUCHERSFORADDRESSREQUEST']._serialized_end=1105
  _globals['_QUERYVOUCHERSFORADDRESSRESPONSE']._serialized_start=1108
  _globals['_QUERYVOUCHERSFORADDRESSRESPONSE']._serialized_end=1268
  _globals['_QUERY']._serialized_start=1271
  _globals['_QUERY']._serialized_end=2432
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.cosmos.staking.v1beta1 import tx_pb2 as cosmos_dot_staking_dot_v1beta1_dot_tx__pb2


class MsgStub(object):
    """Msg defines the staking Msg service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateValidator = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/CreateValidator',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidator.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidatorResponse.FromString,
                _registered_method=True)
        self.EditValidator = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/EditValidator',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidator.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidatorResponse.FromString,
                _registered_method=True)
        self.Delegate = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/Delegate',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegate.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegateResponse.FromString,
                _registered_method=True)
        self.BeginRedelegate = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/BeginRedelegate',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegate.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegateResponse.FromString,
                _registered_method=True)
        self.Undelegate = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/Undelegate',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegate.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegateResponse.FromString,
                _registered_method=True)
        self.CancelUnbondingDelegation = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/CancelUnbondingDelegation',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegation.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegationResponse.FromString,
                _registered_method=True)
        self.UpdateParams = channel.unary_unary(
                '/cosmos.staking.v1beta1.Msg/UpdateParams',
                request_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
                response_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
                _registered_method=True)


class MsgServicer(object):
    """Msg defines the staking Msg service.
    """

    def CreateValidator(self, request, context):
        """CreateValidator defines a method for creating a new validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EditValidator(self, request, context):
        """EditValidator defines a method for editing an existing validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delegate(self, request, context):
        """Delegate defines a method for performing a delegation of coins
        from a delegator to a validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BeginRedelegate(self, request, context):
        """BeginRedelegate defines a method for performing a redelegation
        of coins from a delegator and source validator to a destination validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Undelegate(self, request, context):
        """Undelegate defines a method for performing an undelegation from a
        delegate and a validator.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CancelUnbondingDelegation(self, request, context):
        """CancelUnbondingDelegation defines a method for performing canceling the unbonding delegation
        and delegate back to previous validator.

        Since: cosmos-sdk 0.46
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateParams(self, request, context):
        """UpdateParams defines an operation for updating the x/staking module
        parameters.
        Since: cosmos-sdk 0.47
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateValidator,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidator.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidatorResponse.SerializeToString,
            ),
            'EditValidator': grpc.unary_unary_rpc_method_handler(
                    servicer.EditValidator,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidator.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidatorResponse.SerializeToString,
            ),
            'Delegate': grpc.unary_unary_rpc_method_handler(
                    servicer.Delegate,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegate.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegateResponse.SerializeToString,
            ),
            'BeginRedelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.BeginRedelegate,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegate.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegateResponse.SerializeToString,
            ),
            'Undelegate': grpc.unary_unary_rpc_method_handler(
                    servicer.Undelegate,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegate.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegateResponse.SerializeToString,
            ),
            'CancelUnbondingDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.CancelUnbondingDelegation,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegation.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegationResponse.SerializeToString,
            ),
            'UpdateParams': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateParams,
                    request_deserializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.FromString,
                    response_serializer=cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cosmos.staking.v1beta1.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cosmos.staking.v1beta1.Msg', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Msg defines the staking Msg service.
    """

    @staticmethod
    def CreateValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/CreateValidator',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidator.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCreateValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def EditValidator(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/EditValidator',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidator.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgEditValidatorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/Delegate',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegate.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgDelegateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def BeginRedelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/BeginRedelegate',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegate.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgBeginRedelegateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Undelegate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/Undelegate',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegate.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUndelegateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CancelUnbondingDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/CancelUnbondingDelegation',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegation.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgCancelUnbondingDelegationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateParams(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cosmos.staking.v1beta1.Msg/UpdateParams',
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParams.SerializeToString,
            cosmos_dot_staking_dot_v1beta1_dot_tx__pb2.MsgUpdateParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/events.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.injective.tokenfactory.v1beta1 import authorityMetadata_pb2 as injective_dot_tokenfactory_dot_v1beta1_dot_authorityMetadata__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+injective/tokenfactory/v1beta1/events.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x36injective/tokenfactory/v1beta1/authorityMetadata.proto\"D\n\x12\x45ventCreateTFDenom\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\"x\n\x10\x45ventMintTFDenom\x12+\n\x11recipient_address\x18\x01 \x01(\tR\x10recipientAddress\x12\x37\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"p\n\x0e\x45ventBurnDenom\x12%\n\x0e\x62urner_address\x18\x01 \x01(\tR\rburnerAddress\x12\x37\n\x06\x61mount\x18\x02 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00R\x06\x61mount\"V\n\x12\x45ventChangeTFAdmin\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12*\n\x11new_admin_address\x18\x02 \x01(\tR\x0fnewAdminAddress\"p\n\x17\x45ventSetTFDenomMetadata\x12\x14\n\x05\x64\x65nom\x18\x01 \x01(\tR\x05\x64\x65nom\x12?\n\x08metadata\x18\x02 \x01(\x0b\x32\x1d.cosmos.bank.v1beta1.MetadataB\x04\xc8\xde\x1f\x00R\x08metadataB\x9f\x02\n\"com.injective.tokenfactory.v1beta1B\x0b\x45ventsProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.events_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\013EventsProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_EVENTMINTTFDENOM'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTMINTTFDENOM'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTBURNDENOM'].fields_by_name['amount']._loaded_options = None
  _globals['_EVENTBURNDENOM'].fields_by_name['amount']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTSETTFDENOMMETADATA'].fields_by_name['metadata']._loaded_options = None
  _globals['_EVENTSETTFDENOMMETADATA'].fields_by_name['metadata']._serialized_options = b'\310\336\037\000'
  _globals['_EVENTCREATETFDENOM']._serialized_start=221
  _globals['_EVENTCREATETFDENOM']._serialized_end=289
  _globals['_EVENTMINTTFDENOM']._serialized_start=291
  _globals['_EVENTMINTTFDENOM']._serialized_end=411
  _globals['_EVENTBURNDENOM']._serialized_start=413
  _globals['_EVENTBURNDENOM']._serialized_end=525
  _globals['_EVENTCHANGETFADMIN']._serialized_start=527
  _globals['_EVENTCHANGETFADMIN']._serialized_end=613
  _globals['_EVENTSETTFDENOMMETADATA']._serialized_start=615
  _globals['_EVENTSETTFDENOMMETADATA']._serialized_end=727
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_archiver_rpc.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%exchange/injective_archiver_rpc.proto\x12\x16injective_archiver_rpc\"J\n\x0e\x42\x61lanceRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"k\n\x0f\x42\x61lanceResponse\x12X\n\x12historical_balance\x18\x01 \x01(\x0b\x32).injective_archiver_rpc.HistoricalBalanceR\x11historicalBalance\"/\n\x11HistoricalBalance\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v\"G\n\x0bRpnlRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"_\n\x0cRpnlResponse\x12O\n\x0fhistorical_rpnl\x18\x01 \x01(\x0b\x32&.injective_archiver_rpc.HistoricalRPNLR\x0ehistoricalRpnl\",\n\x0eHistoricalRPNL\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v\"J\n\x0eVolumesRequest\x12\x18\n\x07\x61\x63\x63ount\x18\x01 \x01(\tR\x07\x61\x63\x63ount\x12\x1e\n\nresolution\x18\x02 \x01(\tR\nresolution\"k\n\x0fVolumesResponse\x12X\n\x12historical_volumes\x18\x01 \x01(\x0b\x32).injective_archiver_rpc.HistoricalVolumesR\x11historicalVolumes\"/\n\x11HistoricalVolumes\x12\x0c\n\x01t\x18\x01 \x03(\x11R\x01t\x12\x0c\n\x01v\x18\x02 \x03(\x01R\x01v2\xa1\x02\n\x14InjectiveArchiverRPC\x12Z\n\x07\x42\x61lance\x12&.injective_archiver_rpc.BalanceRequest\x1a\'.injective_archiver_rpc.BalanceResponse\x12Q\n\x04Rpnl\x12#.injective_archiver_rpc.RpnlRequest\x1a$.injective_archiver_rpc.RpnlResponse\x12Z\n\x07Volumes\x12&.injective_archiver_rpc.VolumesRequest\x1a\'.injective_archiver_rpc.VolumesResponseB\xc2\x01\n\x1a\x63om.injective_archiver_rpcB\x19InjectiveArchiverRpcProtoP\x01Z\x19/injective_archiver_rpcpb\xa2\x02\x03IXX\xaa\x02\x14InjectiveArchiverRpc\xca\x02\x14InjectiveArchiverRpc\xe2\x02 InjectiveArchiverRpc\\GPBMetadata\xea\x02\x14InjectiveArchiverRpcb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'exchange.injective_archiver_rpc_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\032com.injective_archiver_rpcB\031InjectiveArchiverRpcProtoP\001Z\031/injective_archiver_rpcpb\242\002\003IXX\252\002\024InjectiveArchiverRpc\312\002\024InjectiveArchiverRpc\342\002 InjectiveArchiverRpc\\GPBMetadata\352\002\024InjectiveArchiverRpc'
  _globals['_BALANCEREQUEST']._serialized_start=65
  _globals['_BALANCEREQUEST']._serialized_end=139
  _globals['_BALANCERESPONSE']._serialized_start=141
  _globals['_BALANCERESPONSE']._serialized_end=248
  _globals['_HISTORICALBALANCE']._serialized_start=250
  _globals['_HISTORICALBALANCE']._serialized_end=297
  _globals['_RPNLREQUEST']._serialized_start=299
  _globals['_RPNLREQUEST']._serialized_end=370
  _globals['_RPNLRESPONSE']._serialized_start=372
  _globals['_RPNLRESPONSE']._serialized_end=467
  _globals['_HISTORICALRPNL']._serialized_start=469
  _globals['_HISTORICALRPNL']._serialized_end=513
  _globals['_VOLUMESREQUEST']._serialized_start=515
  _globals['_VOLUMESREQUEST']._serialized_end=589
  _globals['_VOLUMESRESPONSE']._serialized_start=591
  _globals['_VOLUMESRESPONSE']._serialized_end=698
  _globals['_HISTORICALVOLUMES']._serialized_start=700
  _globals['_HISTORICALVOLUMES']._serialized_end=747
  _globals['_INJECTIVEARCHIVERRPC']._serialized_start=750
  _globals['_INJECTIVEARCHIVERRPC']._serialized_end=1039
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.permissions.v1beta1 import query_pb2 as injective_dot_permissions_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/Params',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.AllNamespaces = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/AllNamespaces',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesResponse.FromString,
                _registered_method=True)
        self.NamespaceByDenom = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/NamespaceByDenom',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomResponse.FromString,
                _registered_method=True)
        self.AddressRoles = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/AddressRoles',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesResponse.FromString,
                _registered_method=True)
        self.AddressesByRole = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/AddressesByRole',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleResponse.FromString,
                _registered_method=True)
        self.VouchersForAddress = channel.unary_unary(
                '/injective.permissions.v1beta1.Query/VouchersForAddress',
                request_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressRequest.SerializeToString,
                response_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Params defines a gRPC query method that returns the permissions module's
        parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllNamespaces(self, request, context):
        """AllNamespaces defines a gRPC query method that returns the permissions
        module's created namespaces.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def NamespaceByDenom(self, request, context):
        """NamespaceByDenom defines a gRPC query method that returns the permissions
        module's namespace associated with the provided denom.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddressRoles(self, request, context):
        """AddressRoles defines a gRPC query method that returns address roles in the
        namespace
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddressesByRole(self, request, context):
        """AddressesByRole defines a gRPC query method that returns a namespace's
        roles associated with the provided address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VouchersForAddress(self, request, context):
        """VouchersForAddress defines a gRPC query method that returns a map of
        vouchers that are held by permissions module for this address, keyed by the
        originator address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'AllNamespaces': grpc.unary_unary_rpc_method_handler(
                    servicer.AllNamespaces,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesResponse.SerializeToString,
            ),
            'NamespaceByDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.NamespaceByDenom,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomResponse.SerializeToString,
            ),
            'AddressRoles': grpc.unary_unary_rpc_method_handler(
                    servicer.AddressRoles,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesResponse.SerializeToString,
            ),
            'AddressesByRole': grpc.unary_unary_rpc_method_handler(
                    servicer.AddressesByRole,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleResponse.SerializeToString,
            ),
            'VouchersForAddress': grpc.unary_unary_rpc_method_handler(
                    servicer.VouchersForAddress,
                    request_deserializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressRequest.FromString,
                    response_serializer=injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.permissions.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.permissions.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/Params',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllNamespaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/AllNamespaces',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAllNamespacesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def NamespaceByDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/NamespaceByDenom',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryNamespaceByDenomResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddressRoles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/AddressRoles',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressRolesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AddressesByRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/AddressesByRole',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryAddressesByRoleResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def VouchersForAddress(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.permissions.v1beta1.Query/VouchersForAddress',
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressRequest.SerializeToString,
            injective_dot_permissions_dot_v1beta1_dot_query__pb2.QueryVouchersForAddressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
